package cn.rankin.common.utils.entity.api;

import java.util.HashMap;
import java.util.Map;
import java.io.Serializable;

public class APIResult<T> implements Serializable {

    private int code;

    private boolean success = false;

    private String message;

    private T data;

    public APIResult() {
    }

    public APIResult(APICode apiCode) {
        this.message = apiCode.getMessage();

        int code = apiCode.getCode();
        this.code = code;

        if (code == 200) {
            this.success = true;
        }
    }

    private APIResult(APICode apiCode, T data) {
        this(apiCode);
        this.data = data;
    }

    public static APIResult ok() {
        return new APIResult(APICodeManager.OK);
    }

    public static APIResult ok(Object value) {
        return new APIResult(APICodeManager.OK, value);
    }

    public static APIResult ok(String name, Object value) {
        return new APIResult(APICodeManager.OK, toMap(name, value));
    }

    public static APIResult ok(Map<String, Object> data) {
        return new APIResult(APICodeManager.OK, data);
    }

    public static APIResult error(APICode apiCode) {
        return new APIResult(apiCode);
    }

    public boolean getSuccess() {
        return success;
    }

    public void setSuccess(boolean success) {
        this.success = success;
    }

    public int getCode() {
        return code;
    }

    public void setCode(int code) {
        this.code = code;
    }

    public String getMessage() {
        return message;
    }

    public void setMessage(String message) {
        this.message = message;
    }

    public T getData() {
        return data;
    }

    public void setData(T data) {
        this.data = data;
    }

    public static <K, V> Map<K, V> toMap(final K k, final V v) {
        return new HashMap<K, V>() {
            {
                this.put(k, v);
            }
        };
    }
}
