package cn.rankin.resourceservice.controller;

import cn.rankin.common.utils.entity.api.APICodeManager;
import cn.rankin.common.utils.entity.api.APIResult;
import cn.rankin.common.utils.entity.page.Page;
import cn.rankin.common.utils.entity.dto.ResourceSearchDTO;
import cn.rankin.common.utils.util.UUIDUtil;
import cn.rankin.resourceservice.entity.Resource;
import cn.rankin.resourceservice.entity.ResourceType;
import cn.rankin.resourceservice.service.ResourceService;
import com.alibaba.fastjson.JSON;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

@Slf4j
@RestController
@RequestMapping(value = "resource")
public class ResourceController {

    @Autowired
    private ResourceService resourceService;

    @RequestMapping(value = "/list")
    public APIResult<Page<Resource>> search(ResourceSearchDTO searchDTO) {
        log.info(JSON.toJSONString(searchDTO));

        // 参数错误返回
        if (searchDTO == null || searchDTO.getType() == null) {
            return APIResult.error(APICodeManager.PARAMETER_ERROR);
        }

        Integer type = searchDTO.getType();
        if (type.intValue() == ResourceType.IMG) {
            // 图片本地取
            return resourceService.search(searchDTO.getCode(), searchDTO.getName(), searchDTO.getSort(), searchDTO.getPageNo(), searchDTO.getPageSize());
        }else {
            // 其他去云平台
            if (searchDTO.getCode() != null) {
                return resourceService.findRemoteByCode(searchDTO.getCode());
            }else {
                resourceService.testAPI();
                return resourceService.findRemotePage(searchDTO);
            }
        }
    }

    @RequestMapping(method = RequestMethod.POST)
    public APIResult<Resource> create(@RequestBody Resource resource) {
        if (!resource.isRight() || resource.getId() != null) {
            return APIResult.error(APICodeManager.PARAMETER_ERROR);
        }

        if (resourceService.exists(resource.getCode())) {
            return APIResult.error(APICodeManager.ALREADY_EXISTS);
        }

        resource.setId(UUIDUtil.getUUID());
        Resource result = resourceService.save(resource);

        return APIResult.ok(result);
    }
}
